summaryrefslogtreecommitdiff
path: root/scripts/link_pyqt.py
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/link_pyqt.py')
-rw-r--r--scripts/link_pyqt.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/scripts/link_pyqt.py b/scripts/link_pyqt.py
index 158cc145d..e2cbddd74 100644
--- a/scripts/link_pyqt.py
+++ b/scripts/link_pyqt.py
@@ -134,16 +134,16 @@ def link_pyqt(executable, venv_path):
venv_path: The path to the virtualenv site-packages.
"""
try:
- get_lib_path(executable, 'PyQt5.sip')
+ get_lib_path(executable, 'PyQt6.sip')
except Error:
# There is no PyQt5.sip, so we need to copy the toplevel sip.
sip_file = get_lib_path(executable, 'sip')
else:
# There is a PyQt5.sip, it'll get copied with the PyQt5 dir.
sip_file = None
sipconfig_file = get_lib_path(executable, 'sipconfig', required=False)
- pyqt_dir = os.path.dirname(get_lib_path(executable, 'PyQt5.QtCore'))
+ pyqt_dir = os.path.dirname(get_lib_path(executable, 'PyQt6.QtCore'))
for path in [sip_file, sipconfig_file, pyqt_dir]:
if path is None:
@@ -134,16 +134,16 @@ def link_pyqt(executable, venv_path):
except Error:
- # There is no PyQt5.sip, so we need to copy the toplevel sip.
+ # There is no PyQt6.sip, so we need to copy the toplevel sip.
sip_file = get_lib_path(executable, 'sip')
else:
@@ -134,16 +134,16 @@ def link_pyqt(executable, venv_path):
sip_file = get_lib_path(executable, 'sip')
else:
- # There is a PyQt5.sip, it'll get copied with the PyQt5 dir.
+ # There is a PyQt6.sip, it'll get copied with the PyQt6 dir.
sip_file = None
sipconfig_file = get_lib_path(executable, 'sipconfig', required=False)